## MCEq data directory

This directory is empty for the package. During the first request for a database file,
it will be downloaded from an online source and stored. For a default installation with
pip, data files will take several hundreds MB of space.